==> checker-3.7.0.jar: annotated-jdk/src/java.base/share/classes/java/util/stream/AbstractSpinedBuffer.java <==
/*
 * Copyright (c) 2012, 2013, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.util.stream;

import org.checkerframework.dataflow.qual.Pure;

abstract class AbstractSpinedBuffer {

    public static final int MIN_CHUNK_POWER;

    public static final int MIN_CHUNK_SIZE;

    public static final int MAX_CHUNK_POWER;

    public static final int MIN_SPINE_SIZE;

    protected final int initialChunkPower;

    protected int elementIndex;

    protected int spineIndex;

    protected long[] priorElementCount;

    protected AbstractSpinedBuffer() {
    }

    protected AbstractSpinedBuffer(int initialCapacity) {
    }

    @Pure
    public boolean isEmpty();

    public long count();

    protected int chunkSize(int n);

    public abstract void clear();
}

==> checker-3.51.0.jar: annotated-jdk/src/java.base/share/classes/java/util/stream/AbstractSpinedBuffer.java <==
/*
 * Copyright (c) 2012, 2013, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.util.stream;

import org.checkerframework.checker.nonempty.qual.EnsuresNonEmptyIf;
import org.checkerframework.dataflow.qual.Pure;

abstract class AbstractSpinedBuffer {

    public static final int MIN_CHUNK_POWER;

    public static final int MIN_CHUNK_SIZE;

    public static final int MAX_CHUNK_POWER;

    public static final int MIN_SPINE_SIZE;

    protected final int initialChunkPower;

    protected int elementIndex;

    protected int spineIndex;

    protected long[] priorElementCount;

    protected AbstractSpinedBuffer() {
    }

    protected AbstractSpinedBuffer(int initialCapacity) {
    }

    @Pure
    @EnsuresNonEmptyIf(result = false, expression = "this")
    public boolean isEmpty();

    public long count();

    protected int chunkSize(int n);

    public abstract void clear();
}
